@@ -122,7 +122,10 @@ class ManagedVariantHandler(object):
         return managed_variant
 
     def managed_variants(
-        self, category=["snv", "sv", "cancer_snv", "cancer_sv"], query_options=None, build=None
+        self,
+        category=["snv", "sv", "cancer_snv", "cancer_sv"],
+        query_options=None,
+        build=None,
     ):
         """Return a cursor to all managed variants of a particular category and build.
 
@@ -141,7 +144,10 @@ class ManagedVariantHandler(object):
         return self.managed_variant_collection.find(query_with_options)
 
     def count_managed_variants(
-        self, category=["snv", "sv", "cancer_snv", "cancer_sv"], build="37", query_options=None
+        self,
+        category=["snv", "sv", "cancer_snv", "cancer_sv"],
+        build="37",
+        query_options=None,
     ):
         """Return count of documents to all managed variants of a particular category and build.
 
@@ -212,7 +218,8 @@ class ManagedVariantHandler(object):
 
         if not result:
             LOG.info(
-                "FAILED deleting managed variant: variant_id %s not found.", managed_variant_id
+                "FAILED deleting managed variant: variant_id %s not found.",
+                managed_variant_id,
             )
 
         return result
