@@ -780,6 +780,7 @@ class VariantHandler(VariantLoader):
             "$and": [
                 {"variant_id": {"$in": variant_ids}},
                 {"institute": institute_id},
+                {"case_id": case_id},
                 {
                     "$or": [
                         {"acmg_classification": {"$exists": True}},
@@ -974,13 +975,12 @@ class VariantHandler(VariantLoader):
 
         return variants_by_type
 
-    def sample_variants(self, variants, sample_name, category="snv"):
-        """Given a list of variants get variant objects found in a specific patient
+    def sample_variant(self, variant_id, sample_name):
+        """Given a variant_id, get the variant document found in a specific patient
 
         Args:
-            variants(list): a list of variant ids
+            variant_id(string): a variant _id
             sample_name(str): a sample display name
-            category(str): 'snv', 'sv' ..
 
         Returns:
             result(iterable(Variant))
@@ -992,8 +992,8 @@ class VariantHandler(VariantLoader):
 
         query = {
             "$and": [
-                {"_id": {"$in": variants}},
-                {"category": category},
+                {"_id": variant_id},
+                {"category": {"$in": ["snv", "sv"]}},
                 {
                     "samples": {
                         "$elemMatch": {
@@ -1005,5 +1005,5 @@ class VariantHandler(VariantLoader):
             ]
         }
 
-        result = self.variant_collection.find(query)
+        result = self.variant_collection.find_one(query)
         return result
