@@ -2,14 +2,11 @@
 import datetime
 import logging
 
-from pymongo import ASCENDING, DESCENDING
-
-LOG = logging.getLogger(__name__)
-
 from anytree import Node, RenderTree
 from anytree.exporter import DictExporter
 from flask import flash
 from flask_login import current_user
+from pymongo import ASCENDING, DESCENDING
 
 from scout.constants import CASE_SEARCH_TERMS, CASE_STATUSES, PHENOTYPE_GROUPS
 from scout.parse.clinvar import clinvar_submission_header, clinvar_submission_lines
@@ -21,6 +18,9 @@ from scout.utils.md5 import generate_md5_key
 
 from .forms import CaseFilterForm
 
+LOG = logging.getLogger(__name__)
+
+
 # Do not assume all cases have a valid track set
 TRACKS = {None: "Rare Disease", "rare": "Rare Disease", "cancer": "Cancer"}
 
@@ -307,7 +307,7 @@ def populate_case_filter_form(params):
     """
     form = CaseFilterForm(params)
     form.search_type.default = params.get("search_type")
-    search_term = form.search_term.data
+    search_term = form.search_term.data or ""
     if ":" in search_term:
         form.search_term.data = search_term[search_term.index(":") + 1 :]  # remove prefix
     return form
