@@ -196,7 +196,12 @@ def test_loqusdb_exe_wrong_version(monkeypatch, loqus_exe, loqus_config):
     with pytest.raises(EnvironmentError):
         # Then the app should not be created because of EnvironmentError
         app = create_app(
-            config=dict(LOQUSDB_SETTINGS={"binary_path": loqus_exe, "loqusdb_config": loqus_config})
+            config=dict(
+                LOQUSDB_SETTINGS={
+                    "binary_path": loqus_exe,
+                    "loqusdb_config": loqus_config,
+                }
+            )
         )
 
 
